import logging
import os
from requests.auth import HTTPBasicAuth

main_directory = os.path.dirname(os.path.abspath(__file__))

log_file = os.path.join(main_directory, "log", "file.log")
table_correspondance_file = os.path.join(main_directory, "files", "correspondance_table.json")
history_file = os.path.join(main_directory, "files", "history.txt")

log_format = '%(asctime)s - %(levelname)s - %(message)s'

# Demandez à l'utilisateur d'entrer les valeurs nécessaires
username = input("Entrez le nom d'utilisateur Jira vous pouvez le moifier plus tard  : ")
api_token = input("Entrez le token API Jira vous pouvez le modifier plus tard: ")
jira_url_base = input("Entrez l'URL de base de Jira vous pouvez le modifier plus tard: ")
project_key = input("Entrez la clé du projet Jira vous pouvez le modifier plus tard : ")
key_issue_type = input("Entrez la clé du type de ticket Jira vous pouvez le modifier plus tard: ")
s1_id_in_jira = input("Entrez l'attribut ID du champ à detourner  vous pouvez le modifier plus tard: ")

headers = {
    "Accept": "application/json",
    "Content-Type": "application/json"
}

statusesS1 = [input(f"Entrez le statut {i + 1} pour S1 : ") for i in range(4)]
jiraStatusName = [input(f"Entrez le nom du statut {i + 1} pour Jira : ") for i in range(4)]
jiraTransition = [input(f"Entrez la transition {i + 1} pour Jira : ") for i in range(4)]

status_dict_S1_to_S2 = {statusS1: jiraStatusName[i] for i, statusS1 in enumerate(statusesS1)}

status_dict_S2_to_S1 = {jiraStatus: statusesS1[i] for i, jiraStatus in enumerate(jiraTransition)}


module_to_use = input("Entrez le module à utiliser comme S1 : ")
class_to_use = input("Entrez la classe à utiliser comme S1 : ")

# Écrivez les valeurs dans le fichier config.py
with open(os.path.join(main_directory, "configtest.py"), 'w') as config_file:
    config_file.write(f"""
import logging
import os
from requests.auth import HTTPBasicAuth
                      
log_file = "{log_file}"
table_correspondance_file = "{table_correspondance_file}"
history_file = "{history_file}"
log_format = '{log_format}'

username = "{username}"
api_token = "{api_token}"

auth = HTTPBasicAuth(username, api_token)
headers = {headers}

jira_url_base = "{jira_url_base}"
project_key = "{project_key}"
key_issue_type = "{key_issue_type}"
s1_id_in_jira = "{s1_id_in_jira}"

statusesS1 = {statusesS1}
jiraStatusName = {jiraStatusName}
jiraTransition = {jiraTransition}

status_dict_S1_to_S2 = {status_dict_S1_to_S2}

status_dict_S2_to_S1 = {status_dict_S2_to_S1}


module_to_use = "{module_to_use}"
class_to_use = "{class_to_use}"
""")




def config_package():

    # config_file_package = '/home/ibtihell/PycharmProjects/sync2jira_package/config/config.py'
    #
    # username = input("Entrez le nom d'utilisateur Jira vous pouvez le moifier plus tard  : ")
    # api_token = input("Entrez le token API Jira vous pouvez le modifier plus tard: ")
    # jira_url_base = input("Entrez l'URL de base de Jira vous pouvez le modifier plus tard: ")
    # project_key = input("Entrez la clé du projet Jira vous pouvez le modifier plus tard : ")
    # key_issue_type = input("Entrez la clé du type de ticket Jira vous pouvez le modifier plus tard: ")
    # s1_id_in_jira = input("Entrez l'attribut ID du champ à detourner  vous pouvez le modifier plus tard: ")
    #
    # module_to_use = input("Entrez le module à utiliser comme S1 : ")
    # class_to_use = input("Entrez la classe à utiliser comme S1 : ")
    #
    # statusesS1 = [input(f"Entrez le statut {i + 1} pour S1 : ") for i in range(4)]
    # jiraStatusName = [input(f"Entrez le nom du statut {i + 1} pour Jira : ") for i in range(4)]
    # jiraTransition = [input(f"Entrez la transition {i + 1} pour Jira : ") for i in range(4)]
    # status_dict_S1_to_S2 = {statusS1: jiraStatusName[i] for i, statusS1 in enumerate(statusesS1)}
    # status_dict_S2_to_S1 = {jiraStatus: statusesS1[i] for i, jiraStatus in enumerate(jiraTransition)}

    with open('config.py', 'w') as fichier_config:
        fichier_config.write(f"""
import logging
import os
from requests.auth import HTTPBasicAuth \n
main_directory = os.path.dirname(os.path.abspath(__file__))
log_file = os.path.join(main_directory, "log", "file.log")
table_correspondance_file = os.path.join(main_directory, "files", "correspondance_table.json")
history_file = os.path.join(main_directory, "files", "history.txt")
log_format = '%(asctime)s - %(levelname)s - %(message)s'\n

headers = {{
    "Accept": "application/json",
    "Content-Type": "application/json"
}}

username = "BillGates" 
#Api token de jira 
api_token = "TATT3xFfGF0nqgTV-RGN17B9CmizmQD0Mmr5ZY-pU0t8TjTzz0lyX0MNJ0XoNdKNy_t4eq9Is3Gw51Mta-kHF0XrEjKUANWzJM1XpRqS_-wSssC"

auth = HTTPBasicAuth(username, api_token)

jira_url_base = "https://example.atlassian.net/"
project_key = "90009"
key_issue_type = "10005"
s1_id_in_jira = "customfield_10054"

statusesS1 = ["status1", "status2", "status3", "status4"]
jiraStatusName = ["To Do", "Pret", "In Progress", "Done"]
jiraTransition = ["En attente", "Pret", "en cours", "Qualifications"]


module_to_use = "implementations.implementation_issue_S3"
class_to_use = "IssueImplementationS3"
""")



import json
import config
from implementations.implementation_issue_S2 import IssueImplementationS2


def save_correspondence(key,id):
    try:

        table = get_correspondence_table()
    except FileNotFoundError:
        table = {}
    table[key] = id

    with open(config.table_correspondance_file, 'w') as f:
        json.dump(table, f)

        
def save_correspondence_dict(correspondence_dict):
    try:
        table = get_correspondence_table()
    except FileNotFoundError:
        table = {}
    table.update(correspondence_dict)

    with open(config.table_correspondance_file, 'w') as f:
        json.dump(table, f)


def get_correspondence_table():
    try:
        with open(config.table_correspondance_file, 'r') as f:
            return json.load(f)
    except FileNotFoundError:
        with open(config.table_correspondance_file, 'w') as f:
            json.dump({}, f)
        return {}


def get_correspondance(id):
    table = get_correspondence_table()
    return table[id]


def save_correspondance_table(key, id):
    if not verifier_existence_key(key) and not verifier_existence_id(id):
        data = get_correspondence_table()
        nouvelle_entree = {"key": key, "id": id}
        data.append(nouvelle_entree)
        with open(config.table_correspondance_file, 'w') as f:
            json.dump(data, f, indent=4)
        return True
    return False


def verifier_existence_key(key):
    data = get_correspondence_table()
    for entry in data:
        if entry.get("key") == key:
            return True
    return False


def verifier_existence_id(id):
    data = get_correspondence_table()
    for entry in data:
        if entry.get("id") == id:
            return True
    return False


def supprimer_key_id(key=None, id=None):
    data = get_correspondence_table()
    if key is not None or id is not None:
        for entry in data:
            if entry.get("key") == key or entry.get("id") == id:
                data.remove(entry)
                with open(config.table_correspondance_file, 'w') as f:
                    json.dump(data, f, indent=4)
                return True
    return False

def rebuild_correspondence_table():
    jql_query = f" s1_id is not  null "
    issue_list = IssueImplementationS2.find_by(jql_query)
    data = {}
    for issue in  issue_list :
        key = issue['key']
        id = issue['fields'][config.s1_id_in_jira]
        data[key] = id 
        with open(config.table_correspondance_file, 'w') as f:
            json.dump(data, f, indent=4)
        




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    # Here is the module name.
    name="synchros1s2",
    # version of the module
    version="0.0.52",
    # Name of Author
    author="wefine",
    # your Email address
    author_email="wefine2529@ebuthor.com",
    # #Small Description about module
    description="Lib",
    # long_description=long_description,
    # Specifying that we are using markdown file for description
    long_description=long_description,
    long_description_content_type="text/markdown",

    # Any link to reach this module, ***if*** you have any webpage or github profile
    # url="https://github.com/username/",
    packages=setuptools.find_packages(),
    #
    # install_requires=[
    #     "fastapi==0.85.1",
    #     "fabric==2.7.1",
    #     "uvicorn==0.19.0",
    #     "pandas==1.5.1",
    #     "openpyxl==3.0.10",
    #     "starlette==0.20.4",
    #     "schedule==1.1.0",
    #     "SQLAlchemy==2.0.16",
    #     "ldap3==2.9.1",
    #     "patchwork==1.0.1",
    #     "pycryptodome==3.17",
    #     "gunicorn==20.1.0",
    #     "pyjwt==2.7.0",
    #     "requests==2.31.0",
    #     "watchdog==3.0.0",
    # ],

    license="MIT",
    # classifiers like program is suitable for python3, just leave as it is.
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
